@@ -123,6 +123,22 @@ class Ports(generic.View):
         return ironic.port_delete(request, params)
 
 
+@urls.register
+class Port(generic.View):
+
+    url_regex = r'ironic/ports/(?P<port_id>[0-9a-f-]+)$'
+
+    @rest_utils.ajax(data_required=True)
+    def patch(self, request, port_id):
+        """Update an Ironic port
+
+        :param request: HTTP request
+        :param port_id: Port id.
+        """
+        patch = request.DATA.get('patch')
+        return ironic.port_update(request, port_id, patch)
+
+
 @urls.register
 class StatesPower(generic.View):
 
@@ -188,6 +204,22 @@ class Maintenance(generic.View):
         return ironic.node_set_maintenance(request, node_id, 'off')
 
 
+@urls.register
+class Validate(generic.View):
+
+    url_regex = r'ironic/nodes/(?P<node_id>[0-9a-f-]+)/validate$'
+
+    @rest_utils.ajax()
+    def get(self, request, node_id):
+        """Validate a specified node
+
+        :param request: HTTP request.
+        :param node_id: Node name or uuid
+        :return: Dictionary of interface statuses
+        """
+        return ironic.node_validate(request, node_id)
+
+
 @urls.register
 class Drivers(generic.View):
 
