@@ -20,34 +20,6 @@
   var POWER_STATE_ON = 'power on';
   var POWER_STATE_OFF = 'power off';
 
-  var DELETE_NODE_TITLE = gettext("Delete Node");
-  var DELETE_NODE_MSG =
-      gettext('Are you sure you want to delete node "%s"? ' +
-              'This action cannot be undone.');
-  var DELETE_NODE_SUCCESS = gettext('Successfully deleted node "%s"');
-  var DELETE_NODE_ERROR = gettext('Unable to delete node "%s"');
-
-  var DELETE_NODES_TITLE = gettext("Delete Nodes");
-  var DELETE_NODES_MSG =
-      gettext('Are you sure you want to delete nodes "%s"? ' +
-              'This action cannot be undone.');
-  var DELETE_NODES_SUCCESS = gettext('Successfully deleted nodes "%s"');
-  var DELETE_NODES_ERROR = gettext('Error deleting nodes "%s"');
-
-  var DELETE_PORT_TITLE = gettext("Delete Port");
-  var DELETE_PORT_MSG =
-      gettext('Are you sure you want to delete port "%s"? ' +
-              'This action cannot be undone.');
-  var DELETE_PORT_SUCCESS = gettext('Successfully deleted port "%s"');
-  var DELETE_PORT_ERROR = gettext('Unable to delete port "%s"');
-
-  var DELETE_PORTS_TITLE = gettext("Delete Ports");
-  var DELETE_PORTS_MSG =
-      gettext('Are you sure you want to delete ports "%s"? ' +
-              'This action cannot be undone.');
-  var DELETE_PORTS_SUCCESS = gettext('Successfully deleted ports "%s"');
-  var DELETE_PORTS_ERROR = gettext('Error deleting ports "%s"');
-
   angular
     .module('horizon.dashboard.admin.ironic')
     .factory('horizon.dashboard.admin.ironic.actions', actions);
@@ -72,9 +44,7 @@
     var service = {
       createPort: createPort,
       deleteNode: deleteNode,
-      deleteNodes: deleteNodes,
       deletePort: deletePort,
-      deletePorts: deletePorts,
       powerOn: powerOn,
       powerOff: powerOff,
       powerOnAll: powerOnNodes,
@@ -82,37 +52,33 @@
       putNodeInMaintenanceMode: putInMaintenanceMode,
       removeNodeFromMaintenanceMode: removeFromMaintenanceMode,
       putAllInMaintenanceMode: putNodesInMaintenanceMode,
-      removeAllFromMaintenanceMode: removeNodesFromMaintenanceMode
+      removeAllFromMaintenanceMode: removeNodesFromMaintenanceMode,
+      setProvisionState: setProvisionState
     };
 
     return service;
 
-    function deleteNode(node) {
-      var labels = {
-        title: DELETE_NODE_TITLE,
-        message: DELETE_NODE_MSG,
-        submit: DELETE_NODE_TITLE,
-        success: DELETE_NODE_SUCCESS,
-        error: DELETE_NODE_ERROR
-      };
+    function deleteNode(nodes) {
       var context = {
-        labels: labels,
-        deleteEntity: ironic.deleteNode,
-        successEvent: ironicEvents.DELETE_NODE_SUCCESS
-      };
-      return deleteModalService.open($rootScope, [node], context);
-    }
-
-    function deleteNodes(nodes) {
-      var labels = {
-        title: DELETE_NODES_TITLE,
-        message: DELETE_NODES_MSG,
-        submit: DELETE_NODES_TITLE,
-        success: DELETE_NODES_SUCCESS,
-        error: DELETE_NODES_ERROR
-      };
-      var context = {
-        labels: labels,
+        labels: {
+          title: ngettext("Delete Node",
+                          "Delete Nodes",
+                          nodes.length),
+          message: ngettext('Are you sure you want to delete node "%s"? ' +
+                            'This action cannot be undone.',
+                            'Are you sure you want to delete nodes "%s"? ' +
+                            'This action cannot be undone.',
+                            nodes.length),
+          submit: ngettext("Delete Node",
+                           "Delete Nodes",
+                           nodes.length),
+          success: ngettext('Successfully deleted node "%s"',
+                            'Successfully deleted nodes "%s"',
+                            nodes.length),
+          error: ngettext('Unable to delete node "%s"',
+                          'Unable to delete nodes "%s"',
+                          nodes.length)
+        },
         deleteEntity: ironic.deleteNode,
         successEvent: ironicEvents.DELETE_NODE_SUCCESS
       };
@@ -191,36 +157,45 @@
       return applyFuncToNodes(removeFromMaintenanceMode, nodes);
     }
 
+    /*
+     * @name horizon.dashboard.admin.ironic.actions.setProvisionState
+     * @description Set the provisioning state of a specified node
+     *
+     * @param {object} args - Object with two properties named 'node'
+     * and 'verb'.
+     *  node: node object.
+     *  verb: string the value of which is the verb used to move
+     *  the node to the desired target state for the node.
+     */
+    function setProvisionState(args) {
+      ironic.setNodeProvisionState(args.node.uuid, args.verb);
+    }
+
     function createPort(node) {
       return createPortService.modal(node);
     }
 
-    function deletePort(port) {
-      var labels = {
-        title: DELETE_PORT_TITLE,
-        message: DELETE_PORT_MSG,
-        submit: DELETE_PORT_TITLE,
-        success: DELETE_PORT_SUCCESS,
-        error: DELETE_PORT_ERROR
-      };
+    function deletePort(ports) {
       var context = {
-        labels: labels,
-        deleteEntity: ironic.deletePort,
-        successEvent: ironicEvents.DELETE_PORT_SUCCESS
-      };
-      return deleteModalService.open($rootScope, [port], context);
-    }
-
-    function deletePorts(ports) {
-      var labels = {
-        title: DELETE_PORTS_TITLE,
-        message: DELETE_PORTS_MSG,
-        submit: DELETE_PORTS_TITLE,
-        success: DELETE_PORTS_SUCCESS,
-        error: DELETE_PORTS_ERROR
-      };
-      var context = {
-        labels: labels,
+        labels: {
+          title: ngettext("Delete Port",
+                          "Delete Ports",
+                          ports.length),
+          message: ngettext('Are you sure you want to delete port "%s"? ' +
+                            'This action cannot be undone.',
+                            'Are you sure you want to delete ports "%s"? ' +
+                            'This action cannot be undone.',
+                            ports.length),
+          submit: ngettext("Delete Port",
+                           "Delete Ports",
+                           ports.length),
+          success: ngettext('Successfully deleted port "%s"',
+                            'Successfully deleted ports "%s"',
+                            ports.length),
+          error: ngettext('Unable to delete port "%s"',
+                          'Unable to delete portss "%s"',
+                          ports.length)
+        },
         deleteEntity: ironic.deletePort,
         successEvent: ironicEvents.DELETE_PORT_SUCCESS
       };
