@@ -18,7 +18,7 @@
   'use strict';
 
   describe('horizon.dashboard.admin.ironic.node-details', function () {
-    var ctrl, $q;
+    var ctrl, $q, nodeStateTransitionService;
     var nodeUuid = "0123abcd-0123-4567-abcd-0123456789ab";
     var nodeName = "herp";
     var numPorts = 2;
@@ -27,8 +27,17 @@
       return '' + index + index + nodeUuid.substring(2);
     }
 
+    function portMacAddr(index) {
+      var mac = '' + index + index;
+      for (var i = 0; i < 5; i++) {
+        mac += ':' + index + index;
+      }
+      return mac;
+    }
+
     function createPort(nodeUuid, index, extra) {
-      var port = {uuid: portUuid(nodeUuid, index)};
+      var port = {uuid: portUuid(nodeUuid, index),
+                  address: portMacAddr(index)};
       if (angular.isDefined(extra)) {
         port.extra = extra;
       }
@@ -36,7 +45,9 @@
     }
 
     function createNode(name, uuid) {
-      return {name: name, uuid: uuid};
+      return {name: name,
+              uuid: uuid,
+              provision_state: 'enroll'};
     }
 
     var ironicAPI = {
@@ -51,13 +62,33 @@
           ports.push(createPort(uuid, i));
         }
         return $q.when({data: {items: ports}});
+      },
+
+      validateNode: function() {
+        return $q.when({});
       }
     };
 
     beforeEach(module('horizon.dashboard.admin.ironic'));
 
-    beforeEach(module('horizon.app.core.openstack-service-api', function($provide) {
-      $provide.value('horizon.app.core.openstack-service-api.ironic', ironicAPI);
+    beforeEach(module(function($provide) {
+      $provide.value('horizon.app.core.openstack-service-api.ironic',
+                     ironicAPI);
+    }));
+
+    beforeEach(module(function($provide) {
+      $provide.value('horizon.framework.widgets.toast.service',
+                     {});
+    }));
+
+    beforeEach(module(function($provide) {
+      $provide.value('horizon.dashboard.admin.ironic.edit-node.service',
+                     {});
+    }));
+
+    beforeEach(module(function($provide) {
+      $provide.value('horizon.dashboard.admin.ironic.maintenance.service',
+                     {});
     }));
 
     beforeEach(inject(function ($injector, _$rootScope_, _$location_) {
@@ -67,38 +98,46 @@
       var $location = _$location_;
       $location.path('/admin/ironic/' + nodeUuid + '/');
 
-      ctrl = controller('horizon.dashboard.admin.ironic.NodeDetailsController', {
-        $scope: scope,
-        $location: $location,
-        'horizon.dashboard.admin.ironic.actions': {},
-        'horizon.dashboard.admin.basePath': '/static'});
+      nodeStateTransitionService = $injector.get(
+        'horizon.dashboard.admin.ironic.node-state-transition.service');
+
+      ctrl = controller(
+        'horizon.dashboard.admin.ironic.NodeDetailsController',
+        {$scope: scope,
+         $location: $location,
+         'horizon.dashboard.admin.ironic.edit-port.service': {},
+         'horizon.dashboard.admin.ironic.actions': {}});
 
       scope.$apply();
     }));
 
-    it('should be defined', function () {
+    it('controller should be defined', function () {
       expect(ctrl).toBeDefined();
     });
 
     it('should have a basePath', function () {
       expect(ctrl.basePath).toBeDefined();
-      expect(ctrl.basePath).toEqual('/static');
     });
 
     it('should have a node', function () {
       expect(ctrl.node).toBeDefined();
-      expect(ctrl.node).toEqual(createNode(nodeName, nodeUuid));
+      var node = createNode(nodeName, nodeUuid);
+      node.id = node.uuid;
+      expect(ctrl.node).toEqual(node);
     });
 
     it('should have ports', function () {
-      expect(ctrl.ports).toBeDefined();
-      expect(ctrl.ports.length).toEqual(numPorts);
+      expect(ctrl.portsSrc).toBeDefined();
+      expect(ctrl.portsSrc.length).toEqual(numPorts);
 
       var ports = [];
-      for (var i = 0; i < ctrl.ports.length; i++) {
-        ports.push(createPort(ctrl.node.uuid, i));
+      for (var i = 0; i < numPorts; i++) {
+        var port = createPort(ctrl.node.uuid, i);
+        port.id = port.uuid;
+        port.name = port.address;
+        ports.push(port);
       }
-      expect(ctrl.ports).toEqual(ports);
+      expect(ctrl.portsSrc).toEqual(ports);
     });
 
     it('should have a uuid regular expression pattern', function () {
@@ -118,5 +157,16 @@
       expect(ctrl.getVifPortId(createPort(ctrl.node.uuid, 1, extra))).
         toEqual("port_uuid");
     });
+
+    it('should have node-state-transitions', function () {
+      expect(ctrl.nodeStateTransitions).toBeDefined();
+      expect(ctrl.nodeStateTransitions).toEqual(
+        nodeStateTransitionService.getTransitions(ctrl.node.provision_state));
+    });
+
+    it('should have node-validation', function () {
+      expect(ctrl.nodeValidation).toBeDefined();
+      expect(ctrl.nodeValidation).toEqual([]);
+    });
   });
 })();
